// generated from rosidl_generator_cpp/resource/idl.hpp.em
// generated code does not contain a copyright notice

#ifndef DIAGNOSTIC_MSGS__MSG__KEY_VALUE_HPP_
#define DIAGNOSTIC_MSGS__MSG__KEY_VALUE_HPP_

#include "diagnostic_msgs/msg/detail/key_value__struct.hpp"
#include "diagnostic_msgs/msg/detail/key_value__builder.hpp"
#include "diagnostic_msgs/msg/detail/key_value__traits.hpp"

#endif  // DIAGNOSTIC_MSGS__MSG__KEY_VALUE_HPP_
