// generated from rosidl_generator_c/resource/idl.h.em
// with input from diagnostic_msgs:srv/SelfTest.idl
// generated code does not contain a copyright notice

#ifndef DIAGNOSTIC_MSGS__SRV__SELF_TEST_H_
#define DIAGNOSTIC_MSGS__SRV__SELF_TEST_H_

#include "diagnostic_msgs/srv/detail/self_test__struct.h"
#include "diagnostic_msgs/srv/detail/self_test__functions.h"
#include "diagnostic_msgs/srv/detail/self_test__type_support.h"

#endif  // DIAGNOSTIC_MSGS__SRV__SELF_TEST_H_
